# coding=utf-8
from pattern.vector import Document, Model, TFIDF, KMEANS, HIERARCHICAL, L1, ORANGE, WEKA

d1 = Document("writing, death, soul, dreams, universe, music, we’re, you’re, I’ve, I’ll", type="moreOpen")
d2 = Document("writing, cant wait, death, 2day, wen, soul, dreams", type="inBetween")
d3 = Document("cant wait, u, wen, mga, miss u, dont, wat, ur, 2day, every 1", type="lessOpen")
	# from: http://www.wwbp.org/personality-wc.html


model = Model(documents=[d1,d2,d3], weight=TFIDF) # creates a vector-model of 'd1+d2+d3'


# *** reading vector-models ***
print "--------------------"
print "model.inverted --> ", model.inverted # vector in dictionary form: (word, set(documents))
print "--------------------"
print "model.vector --> ", model.vector # vector in dictionary form: (word, 0.0)) (?)
print "--------------------"
print "model.vectors --> ", model.vectors # all vectors
print "--------------------"
print "model.features --> ", model.features # all Document.vector.keys(). 
print "--------------------"
print "model.classes --> ", model.classes # all Document.type values. 
print "--------------------"
print "model.weight --> ", model.weight # prints weight-type
print "--------------------"
print "model.density --> ", model.density # Overall word coverage (0.0-1.0). (relative to ?) 
print "--------------------"
print "model.lsa --> ", model.lsa # Concept space, set with Model.reduce(). (?)
print "--------------------"


# *** analysing vector-models ***
print "model.df('writing') --> ", model.df('writing') # doc.freq. of 'writing'
print "--------------------"
print "model.idf('writing') --> ", model.idf('writing') # 1 - (doc.freq. of 'writing')
print "--------------------"
print "model.similarity(d1, d2)  --> ", model.similarity(d1, d2)  
print "--------------------"
print "model.similarity(d2, d3)  --> ", model.similarity(d2, d3)  
print "--------------------"
print "model.neighbors(d1, top=10)  --> ", model.neighbors(d1, top=10) # doc. similarity list
print "--------------------"
print "model.cluster(documents=[d1,d2,d3], method=KMEANS) --> ", model.cluster(documents=[d1,d2,d3], method=HIERARCHICAL) # KMEANS / HIERARCHICAL, clusters vectors (but follows the classes/types) (?)
print "--------------------"
print "model.reduce(dimensions=L1) --> ", model.reduce(dimensions=L1) # L1 | L2 | TOP300 | int (?)
print "--------------------"
print "model.infogain('writing') --> ", model.infogain('writing') # Entropy (≈predictability) (?)
print "--------------------"


# *** saving and exporting vector-models ***
print "model.save('./vector-space-models/example', update=True) --> ", model.save('./vector-space-models/example', update=True) # save model as binary file
print "--------------------"
print "model.export('./vector-space-models/example-in-ORANGE', format=ORANGE)  --> ", model.export('./vector-space-models/example-in-ORANGE', format=ORANGE) # save model as ORANGE type (ready for popular data mining tools)
print "--------------------"
print "model.export('./vector-space-models/example-in-WEKA', format=WEKA)  --> ", model.export('./vector-space-models/example-in-WEKA', format=WEKA) # save model as WEKA type (ready for popular data mining tools)
print "--------------------"




	# from: http://www.clips.ua.ac.be/pages/pattern-vector#model